@@ -1,6 +1,6 @@
 use strict;
 package Kwim::Markdown;
-$Kwim::Markdown::VERSION = '0.0.9';
+$Kwim::Markdown::VERSION = '0.0.10';
 use base 'Kwim::Markup';
 
 # use XXX -with => 'YAML::XS';
@@ -127,4 +127,10 @@ sub phrase_func_badge_travis {
     qq{[![Travis build status](https://travis-ci.org/$args.png?branch=master)](https://travis-ci.org/$args)};
 }
 
+sub phrase_func_badge_coveralls {
+    my ($self, $args) = @_;
+    return unless $args =~ /^(\S+)\/(\S+)$/;
+    qq{[![Coverage Status](https://coveralls.io/repos/$args/badge.png?branch=master)](https://coveralls.io/r/$args?branch=master)};
+}
+
 1;
